@@ -5,37 +5,6 @@ import sys
 
 
 class Ast3ToGAst(AstToGAst):
-    if sys.version_info.minor < 10:
-
-        def visit_alias(self, node):
-            new_node = gast.alias(
-                self._visit(node.name),
-                self._visit(node.asname),
-            )
-            new_node.lineno = new_node.col_offset = None
-            new_node.end_lineno = new_node.end_col_offset = None
-            return new_node
-
-    if sys.version_info.minor < 9:
-
-        def visit_ExtSlice(self, node):
-            new_node = gast.Tuple(self._visit(node.dims), gast.Load())
-            gast.copy_location(new_node, node)
-            return new_node
-
-        def visit_Index(self, node):
-            return self._visit(node.value)
-
-        def visit_Assign(self, node):
-            new_node = gast.Assign(
-                self._visit(node.targets),
-                self._visit(node.value),
-                None,  # type_comment
-            )
-
-            gast.copy_location(new_node, node)
-            new_node.end_lineno = new_node.end_col_offset = None
-            return new_node
 
     if sys.version_info.minor < 8:
         def visit_Module(self, node):
@@ -153,9 +122,7 @@ class Ast3ToGAst(AstToGAst):
                     starred = []
 
                 if node.kwargs:
-                    kw = gast.keyword(None, self._visit(node.kwargs))
-                    gast.copy_location(kw, node.kwargs)
-                    kwargs = [kw]
+                    kwargs = [gast.keyword(None, self._visit(node.kwargs))]
                 else:
                     kwargs = []
             else:
@@ -241,50 +208,6 @@ class Ast3ToGAst(AstToGAst):
 
 
 class GAstToAst3(GAstToAst):
-    if sys.version_info.minor < 10:
-        def visit_alias(self, node):
-            new_node = ast.alias(
-                self._visit(node.name),
-                self._visit(node.asname)
-            )
-            return new_node
-
-    if sys.version_info.minor < 9:
-        def visit_Subscript(self, node):
-            def adjust_slice(s):
-                if isinstance(s, ast.Slice):
-                    return s
-                else:
-                    return ast.Index(s)
-            if isinstance(node.slice, gast.Tuple):
-                if any(isinstance(elt, gast.slice) for elt in node.slice.elts):
-                    new_slice = ast.ExtSlice(
-                        [adjust_slice(x) for x in
-                         self._visit(node.slice.elts)])
-                else:
-                    value = ast.Tuple(self._visit(node.slice.elts), ast.Load())
-                    ast.copy_location(value, node.slice)
-                    new_slice = ast.Index(value)
-            else:
-                new_slice = adjust_slice(self._visit(node.slice))
-            ast.copy_location(new_slice, node.slice)
-
-            new_node = ast.Subscript(
-                self._visit(node.value),
-                new_slice,
-                self._visit(node.ctx),
-            )
-            ast.copy_location(new_node, node)
-            return new_node
-
-    def visit_Assign(self, node):
-        new_node = ast.Assign(
-            self._visit(node.targets),
-            self._visit(node.value),
-        )
-
-        ast.copy_location(new_node, node)
-        return new_node
 
     if sys.version_info.minor < 8:
 
